@@ -1,16 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef NOTESAGENTNOTEDIALOG_H
 #define NOTESAGENTNOTEDIALOG_H
 
-#include <QDialog>
 #include <Item>
+#include <QDialog>
 class QLineEdit;
 class KJob;
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class RichTextEditorWidget;
 }
 class NotesAgentNoteDialog : public QDialog
