@@ -1,25 +1,25 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "notesagentsettingsdialog.h"
 
 #include "knotes-version.h"
-#include <QMenu>
+#include <KAboutData>
 #include <KHelpMenu>
 #include <KLocalizedString>
-#include <QIcon>
-#include <KAboutData>
 #include <KNotifyConfigWidget>
+#include <QIcon>
+#include <QMenu>
 
-#include <QTabWidget>
-#include <KSharedConfig>
-#include <QDialogButtonBox>
 #include <KConfigGroup>
-#include <QPushButton>
-#include <QVBoxLayout>
+#include <KSharedConfig>
 #include <QApplication>
+#include <QDialogButtonBox>
+#include <QPushButton>
+#include <QTabWidget>
+#include <QVBoxLayout>
 
 #include <config/notenetworkconfig.h>
 
@@ -28,7 +28,7 @@ NotesAgentSettingsDialog::NotesAgentSettingsDialog(QWidget *parent)
 {
     setWindowTitle(i18nc("@title:window", "Configure Notes Agent"));
     setWindowIcon(QIcon::fromTheme(QStringLiteral("knotes")));
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     setModal(true);
 
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Help, this);
@@ -38,7 +38,7 @@ NotesAgentSettingsDialog::NotesAgentSettingsDialog(QWidget *parent)
     connect(buttonBox, &QDialogButtonBox::rejected, this, &NotesAgentSettingsDialog::reject);
     connect(okButton, &QPushButton::clicked, this, &NotesAgentSettingsDialog::slotOkClicked);
 
-    auto *tab = new QTabWidget(this);
+    auto tab = new QTabWidget(this);
 
     mNotify = new KNotifyConfigWidget(this);
     mNotify->setApplication(QStringLiteral("akonadi_notes_agent"));
@@ -52,23 +52,20 @@ NotesAgentSettingsDialog::NotesAgentSettingsDialog(QWidget *parent)
     mainLayout->addWidget(buttonBox);
     readConfig();
 
-    KAboutData aboutData = KAboutData(
-        QStringLiteral("notesagent"),
-        i18n("Notes Agent"),
-        QStringLiteral(KNOTES_VERSION),
-        i18n("Notes Agent."),
-        KAboutLicense::GPL_V2,
-        i18n("Copyright (C) 2013-2020 Laurent Montel"));
+    KAboutData aboutData = KAboutData(QStringLiteral("notesagent"),
+                                      i18n("Notes Agent"),
+                                      QStringLiteral(KNOTES_VERSION),
+                                      i18n("Notes Agent."),
+                                      KAboutLicense::GPL_V2,
+                                      i18n("Copyright (C) 2013-2020 Laurent Montel"));
 
-    aboutData.addAuthor(i18n("Laurent Montel"),
-                        i18n("Maintainer"), QStringLiteral("montel@kde.org"));
+    aboutData.addAuthor(i18n("Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
 
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("knotes")));
-    aboutData.setTranslator(i18nc("NAME OF TRANSLATORS", "Your names"),
-                            i18nc("EMAIL OF TRANSLATORS", "Your emails"));
+    aboutData.setTranslator(i18nc("NAME OF TRANSLATORS", "Your names"), i18nc("EMAIL OF TRANSLATORS", "Your emails"));
 
-    auto *helpMenu = new KHelpMenu(this, aboutData, true);
-    //Initialize menu
+    auto helpMenu = new KHelpMenu(this, aboutData, true);
+    // Initialize menu
     QMenu *menu = helpMenu->menu();
     helpMenu->action(KHelpMenu::menuAboutApp)->setIcon(QIcon::fromTheme(QStringLiteral("knotes")));
     buttonBox->button(QDialogButtonBox::Help)->setMenu(menu);
