@@ -1,12 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "notealarmattribute.h"
 
-#include <QDataStream>
 #include <QByteArray>
+#include <QDataStream>
 
 using namespace NoteShared;
 NoteAlarmAttribute::NoteAlarmAttribute()
@@ -20,7 +20,7 @@ NoteAlarmAttribute::~NoteAlarmAttribute()
 
 NoteAlarmAttribute *NoteAlarmAttribute::clone() const
 {
-    auto *attr = new NoteAlarmAttribute();
+    auto attr = new NoteAlarmAttribute();
     attr->setDateTime(dateTime());
     return attr;
 }
@@ -55,7 +55,7 @@ QDateTime NoteAlarmAttribute::dateTime() const
     return mDateTime;
 }
 
-bool NoteAlarmAttribute::operator ==(const NoteAlarmAttribute &other) const
+bool NoteAlarmAttribute::operator==(const NoteAlarmAttribute &other) const
 {
     return mDateTime == other.dateTime();
 }
