@@ -19,13 +19,14 @@ class QPushButton;
 /**
  * A dialog that allows to select network service or request a hostname or IP address.
  */
-namespace NoteShared {
+namespace NoteShared
+{
 class NoteHostDialog : public QDialog
 {
     Q_OBJECT
 public:
     explicit NoteHostDialog(const QString &caption, QWidget *parent = nullptr);
-    ~NoteHostDialog();
+    ~NoteHostDialog() override;
 
     Q_REQUIRED_RESULT QString host() const;
     /**
