@@ -11,18 +11,19 @@
 #define NOTESNETWORKRECEIVER_H
 
 #include "noteshared_export.h"
-#include <QObject>
 #include <QAbstractSocket>
+#include <QObject>
 
 class QTcpSocket;
-namespace NoteShared {
+namespace NoteShared
+{
 class NotesNetworkReceiverPrivate;
 class NOTESHARED_EXPORT NotesNetworkReceiver : public QObject
 {
     Q_OBJECT
 public:
     explicit NotesNetworkReceiver(QTcpSocket *);
-    ~NotesNetworkReceiver();
+    ~NotesNetworkReceiver() override;
 
 Q_SIGNALS:
     void sigNoteReceived(const QString &, const QString &);
