@@ -1,16 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
-#ifndef NOTEUTILS_H
-#define NOTEUTILS_H
+#ifndef NOTESHARED_NOTEUTILS_H
+#define NOTESHARED_NOTEUTILS_H
 
 #include "noteshared_export.h"
 #include <AkonadiCore/Item>
 #include <QString>
 class QWidget;
-namespace NoteShared {
+namespace NoteShared
+{
 class NOTESHARED_EXPORT NoteUtils
 {
 public:
@@ -26,4 +27,4 @@ public:
 };
 }
 
-#endif // NOTEUTILS_H
+#endif // NOTESHARED_NOTEUTILS_H
