@@ -6,19 +6,19 @@
 
 #include "knoteconfigmodule.h"
 
-#include <config-knotes.h>
-#include "knotesglobalconfig.h"
-#include "notesharedglobalconfig.h"
 #include "config/noteactionconfig.h"
 #include "config/notenetworkconfig.h"
+#include "knotesglobalconfig.h"
+#include "notesharedglobalconfig.h"
 #include "print/knoteprintselectthemecombobox.h"
+#include <config-knotes.h>
 
-#include <KAuthorized>
-#include <KLocalizedString>
-#include <KNS3/DownloadDialog>
+#include "configdialog/knotecollectionconfigwidget.h"
 #include "configdialog/knotedisplayconfigwidget.h"
 #include "configdialog/knoteeditorconfigwidget.h"
-#include "configdialog/knotecollectionconfigwidget.h"
+#include <KAuthorized>
+#include <KLocalizedString>
+#include <KNewStuff3/KNS3/QtQuickDialogWrapper>
 
 #include <QCheckBox>
 #include <QLabel>
@@ -32,7 +32,7 @@
 KNoteDisplayConfig::KNoteDisplayConfig(QWidget *parent)
     : KCModule(parent)
 {
-    auto *lay = new QVBoxLayout(this);
+    auto lay = new QVBoxLayout(this);
     QWidget *w = new KNoteDisplayConfigWidget(true);
     lay->addWidget(w);
     lay->addStretch();
@@ -53,7 +53,7 @@ void KNoteDisplayConfig::save()
 KNoteEditorConfig::KNoteEditorConfig(QWidget *parent)
     : KCModule(parent)
 {
-    auto *lay = new QVBoxLayout(this);
+    auto lay = new QVBoxLayout(this);
     QWidget *w = new KNoteEditorConfigWidget(this);
     lay->addWidget(w);
     lay->addStretch();
@@ -74,7 +74,7 @@ void KNoteEditorConfig::load()
 KNoteMiscConfig::KNoteMiscConfig(QWidget *parent)
     : KCModule(parent)
 {
-    auto *lay = new QVBoxLayout(this);
+    auto lay = new QVBoxLayout(this);
     lay->setContentsMargins(0, 0, 0, 0);
 
     QCheckBox *kcfg_SystemTrayShowNotes = new QCheckBox(i18n("Show number of notes in tray icon"), this);
@@ -82,7 +82,7 @@ KNoteMiscConfig::KNoteMiscConfig(QWidget *parent)
     kcfg_SystemTrayShowNotes->setObjectName(QStringLiteral("kcfg_SystemTrayShowNotes"));
     lay->addWidget(kcfg_SystemTrayShowNotes);
 
-    auto *hbox = new QHBoxLayout;
+    auto hbox = new QHBoxLayout;
     lay->addLayout(hbox);
     QLabel *label_DefaultTitle = new QLabel(i18n("Default Title:"), this);
     hbox->addWidget(label_DefaultTitle);
@@ -124,16 +124,16 @@ void KNoteMiscConfig::defaults()
 
 void KNoteMiscConfig::slotHelpLinkClicked(const QString &)
 {
-    const QString help
-        = i18n("<qt>"
-               "<p>You can customize title note. "
-               "You can use:</p>"
-               "<ul>"
-               "<li>%d current date (short format)</li>"
-               "<li>%l current date (long format)</li>"
-               "<li>%t current time</li>"
-               "</ul>"
-               "</qt>");
+    const QString help = i18n(
+        "<qt>"
+        "<p>You can customize title note. "
+        "You can use:</p>"
+        "<ul>"
+        "<li>%d current date (short format)</li>"
+        "<li>%l current date (long format)</li>"
+        "<li>%t current time</li>"
+        "</ul>"
+        "</qt>");
 
     QWhatsThis::showText(QCursor::pos(), help);
 }
@@ -141,10 +141,10 @@ void KNoteMiscConfig::slotHelpLinkClicked(const QString &)
 KNotePrintConfig::KNotePrintConfig(QWidget *parent)
     : KCModule(parent)
 {
-    auto *lay = new QVBoxLayout(this);
+    auto lay = new QVBoxLayout(this);
     QWidget *w = new QWidget(this);
     lay->addWidget(w);
-    auto *layout = new QGridLayout(w);
+    auto layout = new QGridLayout(w);
     layout->setContentsMargins(0, 0, 0, 0);
 
     QLabel *label_PrintAction = new QLabel(i18n("Theme:"), this);
@@ -155,7 +155,7 @@ KNotePrintConfig::KNotePrintConfig(QWidget *parent)
     label_PrintAction->setBuddy(mSelectTheme);
     layout->addWidget(mSelectTheme, 0, 1);
     if (KAuthorized::authorize(QStringLiteral("ghns"))) {
-        auto *getNewTheme = new QToolButton;
+        auto getNewTheme = new QToolButton;
         getNewTheme->setIcon(QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")));
         getNewTheme->setToolTip(i18n("Download new printing themes"));
         connect(getNewTheme, &QToolButton::clicked, this, &KNotePrintConfig::slotDownloadNewThemes);
@@ -167,15 +167,9 @@ KNotePrintConfig::KNotePrintConfig(QWidget *parent)
 
 void KNotePrintConfig::slotDownloadNewThemes()
 {
-    QPointer<KNS3::DownloadDialog> downloadThemesDialog
-        = new KNS3::DownloadDialog(QStringLiteral("knotes_printing_theme.knsrc"));
-
-    if (downloadThemesDialog->exec()) {
-        if (!downloadThemesDialog->changedEntries().isEmpty()) {
-            mSelectTheme->loadThemes();
-        }
+    if (!KNS3::QtQuickDialogWrapper(QStringLiteral("kwinswitcher.knsrc")).exec().isEmpty()) {
+        mSelectTheme->loadThemes();
     }
-    delete downloadThemesDialog;
 }
 
 void KNotePrintConfig::slotThemeChanged()
@@ -202,7 +196,7 @@ void KNotePrintConfig::defaults()
 KNoteCollectionConfig::KNoteCollectionConfig(QWidget *parent)
     : KCModule(parent)
 {
-    auto *lay = new QHBoxLayout(this);
+    auto lay = new QHBoxLayout(this);
     mCollectionConfigWidget = new KNoteCollectionConfigWidget;
     lay->addWidget(mCollectionConfigWidget);
     connect(mCollectionConfigWidget, &KNoteCollectionConfigWidget::emitChanged, this, &KNoteCollectionConfig::markAsChanged);
@@ -216,5 +210,5 @@ void KNoteCollectionConfig::save()
 
 void KNoteCollectionConfig::load()
 {
-    //Nothing
+    // Nothing
 }
