@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,11 +8,13 @@
 
 #include <KCModule>
 #include <KViewStateMaintainer>
-namespace Akonadi {
+namespace Akonadi
+{
 class ETMViewStateSaver;
 }
 
-namespace PimCommon {
+namespace PimCommon
+{
 class CheckedCollectionWidget;
 }
 
