@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -25,7 +25,7 @@ class KNOTES_EXPORT KNotePrintObject : public QObject
     Q_PROPERTY(QString backgroundColorName READ backgroundColorName)
 public:
     explicit KNotePrintObject(const Akonadi::Item &item, QObject *parent = nullptr);
-    ~KNotePrintObject();
+    ~KNotePrintObject() override;
 
     Q_REQUIRED_RESULT QString description() const;
     Q_REQUIRED_RESULT QString name() const;
@@ -34,6 +34,7 @@ public:
     Q_REQUIRED_RESULT QString alarm() const;
     Q_REQUIRED_RESULT bool isLock() const;
     Q_REQUIRED_RESULT QString backgroundColorName() const;
+
 private:
     Akonadi::Item mItem;
 };
